@@ -20,7 +20,7 @@
  *
  */
 
-/* $Id: xmalloc.c,v 1.6 2007-04-09 16:57:40 timo Exp $ */
+/* $Id: xmalloc.c,v 1.11 2008-05-23 06:43:22 timo Exp $ */
 
 #include "ffe.h"
 #include <stdlib.h>
@@ -52,3 +52,40 @@ xrealloc (void *ptr, size_t size)
     if (value == NULL) panic("Out of memory",NULL,NULL);
     return value;
 }
+
+FILE *
+xxfopen(char *name, char *mode, char bin_asc)
+{
+    register FILE *ret;
+
+    ret = fopen(name,mode);
+    if(ret == NULL) panic("Error in opening file",name,strerror(errno));
+
+#if defined(HAVE_SETMODE) && defined(WIN32)
+    if(bin_asc == 'a') setmode(fileno(ret),O_TEXT);
+    if(bin_asc == 'b') setmode(fileno(ret),O_BINARY);
+#endif
+    return ret;
+}
+
+FILE *
+xfopen(char *name, char *mode)
+{
+    return xxfopen(name,mode,'a');
+}
+
+FILE *
+xfopenb(char *name, char *mode)
+{
+    return xxfopen(name,mode,'b'); 
+}
+
+void
+file_to_text(FILE *fp)
+{
+#if defined(HAVE_SETMODE) && defined(WIN32)
+    setmode(fileno(fp),O_TEXT);
+#endif
+}
+
+
